from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Directory, String, Int, Boolean, Float, File

Gsnapl_Sse42_V0_1_0 = CommandToolBuilder(tool="gsnapl.sse42", base_command=["gsnapl.sse42"], inputs=[ToolInput(tag="in_dir", input_type=Directory(optional=True), prefix="--dir", doc=InputDocumentation(doc="Genome directory.  Default (as specified by --with-gmapdb to the configure program) is\n/usr/local/share")), ToolInput(tag="in_db", input_type=String(optional=True), prefix="--db", doc=InputDocumentation(doc="Genome database")), ToolInput(tag="in_use_local_db", input_type=Int(optional=True), prefix="--use-localdb", doc=InputDocumentation(doc="Whether to use the local hash tables, which help with finding extensions to the ends\nof alignments in the presence of splicing or indels (0=no, 1=yes if available (default))")), ToolInput(tag="in_transcript_dir", input_type=Directory(optional=True), prefix="--transcriptdir", doc=InputDocumentation(doc="Transcriptome directory.  Default is the value for --dir above")), ToolInput(tag="in_transcript_db", input_type=String(optional=True), prefix="--transcriptdb", doc=InputDocumentation(doc="Transcriptome database")), ToolInput(tag="in_use_transcriptome_only", input_type=Boolean(optional=True), prefix="--use-transcriptome-only", doc=InputDocumentation(doc="Use only the transcriptome index and not the genome index")), ToolInput(tag="in_km_er", input_type=Int(optional=True), prefix="--kmer", doc=InputDocumentation(doc="kmer size to use in genome database (allowed values: 16 or less)\nIf not specified, the program will find the highest available\nkmer size in the genome database")), ToolInput(tag="in_sampling", input_type=Int(optional=True), prefix="--sampling", doc=InputDocumentation(doc="Sampling to use in genome database.  If not specified, the program\nwill find the smallest available sampling value in the genome database\nwithin selected k-mer size")), ToolInput(tag="in_part", input_type=Int(optional=True), prefix="--part", doc=InputDocumentation(doc="/INT             Process only the i-th out of every n sequences\ne.g., 0/100 or 99/100 (useful for distributing jobs\nto a computer farm).")), ToolInput(tag="in_input_buffer_size", input_type=Int(optional=True), prefix="--input-buffer-size", doc=InputDocumentation(doc="Size of input buffer (program reads this many sequences\nat a time for efficiency) (default 1000)")), ToolInput(tag="in_barcode_length", input_type=Int(optional=True), prefix="--barcode-length", doc=InputDocumentation(doc="Amount of barcode to remove from start of every read before alignment\n(default 0)")), ToolInput(tag="in_end_trim_length", input_type=Int(optional=True), prefix="--endtrim-length", doc=InputDocumentation(doc="Amount of trim to remove from the end of every read before alignment\n(default 0)")), ToolInput(tag="in_orientation", input_type=String(optional=True), prefix="--orientation", doc=InputDocumentation(doc="Orientation of paired-end reads\nAllowed values: FR (fwd-rev, or typical Illumina; default),\nRF (rev-fwd, for circularized inserts), or FF (fwd-fwd, same strand)")), ToolInput(tag="in_fast_q_id_start", input_type=Int(optional=True), prefix="--fastq-id-start", doc=InputDocumentation(doc="Starting position of identifier in FASTQ header, space-delimited (>= 1)")), ToolInput(tag="in_fast_q_id_end", input_type=Int(optional=True), prefix="--fastq-id-end", doc=InputDocumentation(doc="Ending position of identifier in FASTQ header, space-delimited (>= 1)\nExamples:\n@HWUSI-EAS100R:6:73:941:1973#0/1\nstart=1, end=1 (default) => identifier is HWUSI-EAS100R:6:73:941:1973#0\n@SRR001666.1 071112_SLXA-EAS1_s_7:5:1:817:345 length=36\nstart=1, end=1  => identifier is SRR001666.1\nstart=2, end=2  => identifier is 071112_SLXA-EAS1_s_7:5:1:817:345\nstart=1, end=2  => identifier is SRR001666.1 071112_SLXA-EAS1_s_7:5:1:817:345")), ToolInput(tag="in_force_single_end", input_type=Boolean(optional=True), prefix="--force-single-end", doc=InputDocumentation(doc="When multiple FASTQ files are provided on the command line, GSNAP assumes\nthey are matching paired-end files.  This flag treats each file as single-end.")), ToolInput(tag="in_filter_chastity", input_type=String(optional=True), prefix="--filter-chastity", doc=InputDocumentation(doc="Skips reads marked by the Illumina chastity program.  Expecting a string\nafter the accession having a 'Y' after the first colon, like this:\n@accession 1:Y:0:CTTGTA\nwhere the 'Y' signifies filtering by chastity.\nValues: off (default), either, both.  For 'either', a 'Y' on either end\nof a paired-end read will be filtered.  For 'both', a 'Y' is required\non both ends of a paired-end read (or on the only end of a single-end read).")), ToolInput(tag="in_allow_pe_name_mismatch", input_type=Boolean(optional=True), prefix="--allow-pe-name-mismatch", doc=InputDocumentation(doc="Allows accession names of reads to mismatch in paired-end files")), ToolInput(tag="in_interleaved", input_type=Boolean(optional=True), prefix="--interleaved", doc=InputDocumentation(doc="Input is in interleaved format (one read per line, tab-delimited")), ToolInput(tag="in_gunzip", input_type=Boolean(optional=True), prefix="--gunzip", doc=InputDocumentation(doc="Uncompress gzipped input files")), ToolInput(tag="in_b_unzip_two", input_type=Boolean(optional=True), prefix="--bunzip2", doc=InputDocumentation(doc="Uncompress bzip2-compressed input files")), ToolInput(tag="in_batch", input_type=Int(optional=True), prefix="--batch", doc=InputDocumentation(doc="Batch mode (default = 2)")), ToolInput(tag="in_use_shared_memory", input_type=Int(optional=True), prefix="--use-shared-memory", doc=InputDocumentation(doc="If 1, then allocated memory is shared among all processes on this node\nIf 0 (default), then each process has private allocated memory")), ToolInput(tag="in_preload_shared_memory", input_type=Boolean(optional=True), prefix="--preload-shared-memory", doc=InputDocumentation(doc="Load files indicated by --batch mode into shared memory for use by other\nGMAP/GSNAP processes on this node, and then exit.  Ignore any input files.")), ToolInput(tag="in_unload_shared_memory", input_type=Boolean(optional=True), prefix="--unload-shared-memory", doc=InputDocumentation(doc="Unload files indicated by --batch mode into shared memory, or allow them\nto be unloaded when existing GMAP/GSNAP processes on this node are finished\nwith them.  Ignore any input files.")), ToolInput(tag="in_max_mismatches", input_type=Float(optional=True), prefix="--max-mismatches", doc=InputDocumentation(doc="Maximum number of mismatches allowed (if not specified, then\nGSNAP tries to find the best possible match in the genome)\nIf specified between 0.0 and 1.0, then treated as a fraction\nof each read length.  Otherwise, treated as an integral number\nof mismatches (including indel and splicing penalties).\nDefault is to be unspecified (to find the best possible match)")), ToolInput(tag="in_max_ref_mismatches", input_type=Float(optional=True), prefix="--max-ref-mismatches", doc=InputDocumentation(doc="If GSNAP is run under SNP-tolerant or masked genome mode, then the")), ToolInput(tag="in_min_coverage", input_type=Float(optional=True), prefix="--min-coverage", doc=InputDocumentation(doc="Minimum coverage required for an alignment.\nIf specified between 0.0 and 1.0, then treated as a fraction\nof each read length.  Otherwise, treated as an integral number\nof base pairs.  Default value is 0.5.")), ToolInput(tag="in_filter_within_trims", input_type=Int(optional=True), prefix="--filter-within-trims", doc=InputDocumentation(doc="Whether to count mismatches in trimmed part of alignment (1, yes) or\nmismatches to the ends of the read (0, no), when applying the\n--max-mismatches and --max-ref-mismatches parameters.\nDefault for RNA-Seq is 1 (yes) so we can allow for\nreads that align past the ends of an exon.  Default for DNA-Seq\nis 0 (no).\nFor RNA-Seq, trimmed ends should be ignored, because trimming\nis performed at probable splice sites, to allow for reads that\nalign past the ends of an exon.")), ToolInput(tag="in_query_unk_mismatch", input_type=Int(optional=True), prefix="--query-unk-mismatch", doc=InputDocumentation(doc="Whether to count unknown (N) characters in the query as a mismatch\n(0=no (default), 1=yes)")), ToolInput(tag="in_genome_unk_mismatch", input_type=Int(optional=True), prefix="--genome-unk-mismatch", doc=InputDocumentation(doc="Whether to count unknown (N) characters in the genome as a mismatch\n(0=no, 1=yes).  If --use-mask is specified, default is no, otherwise yes.")), ToolInput(tag="in_in_del_penalty", input_type=Int(optional=True), prefix="--indel-penalty", doc=InputDocumentation(doc="Penalty for an indel (default 2).\nCounts against mismatches allowed.  To find indels, make\nindel-penalty less than or equal to max-mismatches.\nA value < 2 can lead to false positives at read ends")), ToolInput(tag="in_in_del_end_length", input_type=Int(optional=True), prefix="--indel-endlength", doc=InputDocumentation(doc="Minimum length at end required for indel alignments (default 4)")), ToolInput(tag="in_max_middle_insertions", input_type=Float(optional=True), prefix="--max-middle-insertions", doc=InputDocumentation(doc="Maximum number of middle insertions allowed (default is 0.2)\nIf specified between 0.0 and 1.0, then treated as a fraction\nof each read length.  Otherwise, treated as an integral number\nof base pairs")), ToolInput(tag="in_max_middle_deletions", input_type=Float(optional=True), prefix="--max-middle-deletions", doc=InputDocumentation(doc="Maximum number of middle deletions allowed (default 0.2)\nIf specified between 0.0 and 1.0, then treated as a fraction\nof each read length.  Otherwise, treated as an integral number\nof base pairs")), ToolInput(tag="in_max_end_insertions", input_type=Int(optional=True), prefix="--max-end-insertions", doc=InputDocumentation(doc="Maximum number of end insertions allowed (default 3)")), ToolInput(tag="in_max_end_deletions", input_type=Int(optional=True), prefix="--max-end-deletions", doc=InputDocumentation(doc="Maximum number of end deletions allowed (default 6)")), ToolInput(tag="in_suboptimal_levels", input_type=Int(optional=True), prefix="--suboptimal-levels", doc=InputDocumentation(doc="Report suboptimal hits beyond best hit (default 0)\nAll hits with best score plus suboptimal-levels are reported")), ToolInput(tag="in_adapter_strip", input_type=String(optional=True), prefix="--adapter-strip", doc=InputDocumentation(doc="Method for removing adapters from reads.  Currently allowed values: off, paired.\nDefault is 'off'.  To turn on, specify 'paired', which removes adapters\nfrom paired-end reads if they appear to be present.")), ToolInput(tag="in_trim_in_del_score", input_type=Int(optional=True), prefix="--trim-indel-score", doc=InputDocumentation(doc="Score to use for indels when trimming at ends.  To turn off trimming,\nspecify 0.  Default is -2 for both RNA-Seq and DNA-Seq.  Warning:\nTurning trimming off in RNA-Seq can give false positive indels\nat the ends of reads")), ToolInput(tag="in_use_mask", input_type=String(optional=True), prefix="--use-mask", doc=InputDocumentation(doc="Use genome containing masks (e.g. for non-exons) for scoring preference")), ToolInput(tag="in_snps_dir", input_type=Directory(optional=True), prefix="--snpsdir", doc=InputDocumentation(doc="Directory for SNPs index files (created using snpindex) (default is\nlocation of genome index files specified using -D and -d)")), ToolInput(tag="in_use_snps", input_type=String(optional=True), prefix="--use-snps", doc=InputDocumentation(doc="Use database containing known SNPs (in <STRING>.iit, built\npreviously using snpindex) for tolerance to SNPs")), ToolInput(tag="in_c_met_dir", input_type=Directory(optional=True), prefix="--cmetdir", doc=InputDocumentation(doc="Directory for methylcytosine index files (created using cmetindex)\n(default is location of genome index files specified using -D, -V, and -d)")), ToolInput(tag="in_atoi_dir", input_type=Directory(optional=True), prefix="--atoidir", doc=InputDocumentation(doc="Directory for A-to-I RNA editing index files (created using atoiindex)\n(default is location of genome index files specified using -D, -V, and -d)")), ToolInput(tag="in_alignment_mode_standard", input_type=String(optional=True), prefix="--mode", doc=InputDocumentation(doc="Alignment mode: standard (default), cmet-stranded, cmet-nonstranded,\natoi-stranded, atoi-nonstranded, ttoc-stranded, or ttoc-nonstranded.\nNon-standard modes requires you to have previously run the cmetindex\nor atoiindex programs (which also cover the ttoc modes) on the genome")), ToolInput(tag="in_n_threads", input_type=Int(optional=True), prefix="--nthreads", doc=InputDocumentation(doc="Number of worker threads")), ToolInput(tag="in_max_anchors", input_type=Int(optional=True), prefix="--max-anchors", doc=InputDocumentation(doc="Controls number of candidate segments returned by the complete set algorithm\nDefault is 10.  Can be increased to higher values to solve alignments with\nevenly spaced mismatches at close distances.  However, higher values will\ncause GSNAP to run more slowly.  A value of 1000, for example, slows down\nthe program by a factor of 10 or so.  Therefore, change this value only if\nabsolutely necessary.")), ToolInput(tag="in_find_dna_chimeras", input_type=Int(optional=True), prefix="--find-dna-chimeras", doc=InputDocumentation(doc="Look for distant splicing involving poor splice sites (0=no, 1=yes (default))\nCurrent implementation improves even RNA-Seq alignments at poor splice sites\nso it is now on by default.")), ToolInput(tag="in_novel_splicing", input_type=Int(optional=True), prefix="--novelsplicing", doc=InputDocumentation(doc="Look for novel splicing (0=no (default), 1=yes)")), ToolInput(tag="in_splicing_dir", input_type=Directory(optional=True), prefix="--splicingdir", doc=InputDocumentation(doc="Directory for splicing involving known sites or known introns,\nas specified by the -s or --use-splicing flag (default is\ndirectory computed from -D and -d flags).  Note: can\njust give full pathname to the -s flag instead.")), ToolInput(tag="in_use_splicing", input_type=String(optional=True), prefix="--use-splicing", doc=InputDocumentation(doc="Look for splicing involving known sites or known introns\n(in <STRING>.iit), at short or long distances\nSee README instructions for the distinction between known sites\nand known introns")), ToolInput(tag="in_am_big_splice_no_clip", input_type=Boolean(optional=True), prefix="--ambig-splice-noclip", doc=InputDocumentation(doc="For ambiguous known splicing at ends of the read, do not clip at the\nsplice site, but extend instead into the intron.  This flag makes\nsense only if you provide the --use-splicing flag, and you are trying\nto eliminate all soft clipping with --trim-mismatch-score=0")), ToolInput(tag="in_local_splice_dist", input_type=Int(optional=True), prefix="--localsplicedist", doc=InputDocumentation(doc="Definition of local novel splicing event (default 200000)")), ToolInput(tag="in_novel_end_splice_dist", input_type=Int(optional=True), prefix="--novelend-splicedist", doc=InputDocumentation(doc="Distance to look for novel splices at the ends of reads (default 80000)")), ToolInput(tag="in_local_splice_penalty", input_type=Int(optional=True), prefix="--local-splice-penalty", doc=InputDocumentation(doc="Penalty for a local splice (default 0).  Counts against mismatches allowed")), ToolInput(tag="in_distant_splice_penalty", input_type=Int(optional=True), prefix="--distant-splice-penalty", doc=InputDocumentation(doc="Penalty for a distant splice (default 1).  A distant splice is one where\nthe intron length exceeds the value of -w, or --localsplicedist, or is an\ninversion, scramble, or translocation between two different chromosomes\nCounts against mismatches allowed")), ToolInput(tag="in_distant_splice_end_length", input_type=Int(optional=True), prefix="--distant-splice-endlength", doc=InputDocumentation(doc="Minimum length at end required for distant spliced alignments (default 20, min\nallowed is the value of -k, or kmer size)")), ToolInput(tag="in_short_end_splice_end_length", input_type=Int(optional=True), prefix="--shortend-splice-endlength", doc=InputDocumentation(doc="Minimum length at end required for short-end spliced alignments (default 2,\nbut unless known splice sites are provided with the -s flag, GSNAP may still\nneed the end length to be the value of -k, or kmer size to find a given splice")), ToolInput(tag="in_distant_splice_identity", input_type=Float(optional=True), prefix="--distant-splice-identity", doc=InputDocumentation(doc="Minimum identity at end required for distant spliced alignments (default 0.95)")), ToolInput(tag="in_anti_stranded_penalty", input_type=Int(optional=True), prefix="--antistranded-penalty", doc=InputDocumentation(doc="(Not currently implemented, since it leads to poor results)\nPenalty for antistranded splicing when using stranded RNA-Seq protocols.\nA positive value, such as 1, expects antisense on the first read\nand sense on the second read.  Default is 0, which treats sense and antisense\nequally well")), ToolInput(tag="in_merge_distant_same_chr", input_type=Boolean(optional=True), prefix="--merge-distant-samechr", doc=InputDocumentation(doc="Report distant splices on the same chromosome as a single splice, if possible.\nWill produce a single SAM line instead of two SAM lines, which is also done\nfor translocations, inversions, and scramble events")), ToolInput(tag="in_pair_max_dna", input_type=Int(optional=True), prefix="--pairmax-dna", doc=InputDocumentation(doc="Max total genomic length for DNA-Seq paired reads, or other reads\nwithout splicing (default 2000).  Used if -N or -s is not specified.\nThis value is also used for circular chromosomes when splicing in\nlinear chromosomes is allowed")), ToolInput(tag="in_pair_max_rna", input_type=Int(optional=True), prefix="--pairmax-rna", doc=InputDocumentation(doc="Max total genomic length for RNA-Seq paired reads, or other reads\nthat could have a splice (default 200000).  Used if -N or -s is specified.\nShould probably match the value for -w, --localsplicedist.")), ToolInput(tag="in_pair_expect", input_type=Int(optional=True), prefix="--pairexpect", doc=InputDocumentation(doc="Expected paired-end length, used for calling splices in medial part\nof paired-end reads (default 500).  Was turned off in previous versions, but reinstated.")), ToolInput(tag="in_pair_dev", input_type=Int(optional=True), prefix="--pairdev", doc=InputDocumentation(doc="Allowable deviation from expected paired-end length, used for\ncalling splices in medial part of paired-end reads (default 100).\nWas turned off in previous versions, but reinstated.")), ToolInput(tag="in_quality_protocol", input_type=Int(optional=True), prefix="--quality-protocol", doc=InputDocumentation(doc="Protocol for input quality scores.  Allowed values:\nillumina (ASCII 64-126) (equivalent to -J 64 -j -31)\nsanger   (ASCII 33-126) (equivalent to -J 33 -j 0)\nDefault is sanger (no quality print shift)\nSAM output files should have quality scores in sanger protocol\nOr you can customize this behavior with these flags:")), ToolInput(tag="in_quality_zero_score", input_type=Int(optional=True), prefix="--quality-zero-score", doc=InputDocumentation(doc="FASTQ quality scores are zero at this ASCII value\n(default is 33 for sanger protocol; for Illumina, select 64)")), ToolInput(tag="in_quality_print_shift", input_type=Int(optional=True), prefix="--quality-print-shift", doc=InputDocumentation(doc="Shift FASTQ quality scores by this amount in output\n(default is 0 for sanger protocol; to change Illumina input\nto Sanger output, select -31)")), ToolInput(tag="in_n_paths", input_type=Int(optional=True), prefix="--npaths", doc=InputDocumentation(doc="Maximum number of paths to print (default 100).")), ToolInput(tag="in_quiet_if_excessive", input_type=Boolean(optional=True), prefix="--quiet-if-excessive", doc=InputDocumentation(doc="If more than maximum number of paths are found,\nthen nothing is printed.")), ToolInput(tag="in_ordered", input_type=Boolean(optional=True), prefix="--ordered", doc=InputDocumentation(doc="Print output in same order as input (relevant\nonly if there is more than one worker thread)")), ToolInput(tag="in_show_ref_diff", input_type=Boolean(optional=True), prefix="--show-refdiff", doc=InputDocumentation(doc="For GSNAP output in SNP-tolerant alignment, shows all differences\nrelative to the reference genome as lower case (otherwise, it shows\nall differences relative to both the reference and alternate genome)")), ToolInput(tag="in_clip_overlap", input_type=Boolean(optional=True), prefix="--clip-overlap", doc=InputDocumentation(doc="For paired-end reads whose alignments overlap, clip the overlapping region.")), ToolInput(tag="in_merge_overlap", input_type=Boolean(optional=True), prefix="--merge-overlap", doc=InputDocumentation(doc="For paired-end reads whose alignments overlap, merge the two ends into a single end (beta implementation)")), ToolInput(tag="in_print_snps", input_type=Boolean(optional=True), prefix="--print-snps", doc=InputDocumentation(doc="Print detailed information about SNPs in reads (works only if -v also selected)\n(not fully implemented yet)")), ToolInput(tag="in_fails_only", input_type=Boolean(optional=True), prefix="--failsonly", doc=InputDocumentation(doc="Print only failed alignments, those with no results")), ToolInput(tag="in_no_fails", input_type=Boolean(optional=True), prefix="--nofails", doc=InputDocumentation(doc="Exclude printing of failed alignments")), ToolInput(tag="in_format", input_type=Int(optional=True), prefix="--format", doc=InputDocumentation(doc="Another format type, other than default.\nCurrently implemented: sam, m8 (BLAST tabular format)")), ToolInput(tag="in_split_output", input_type=File(optional=True), prefix="--split-output", doc=InputDocumentation(doc="Basename for multiple-file output, separately for nomapping,\nhalfmapping_uniq, halfmapping_mult, unpaired_uniq, unpaired_mult,\npaired_uniq, paired_mult, concordant_uniq, and concordant_mult results")), ToolInput(tag="in_output_file", input_type=File(optional=True), prefix="--output-file", doc=InputDocumentation(doc="File name for a single stream of output results.")), ToolInput(tag="in_failed_input", input_type=File(optional=True), prefix="--failed-input", doc=InputDocumentation(doc="Print completely failed alignments as input FASTA or FASTQ format,\nto the given file, appending .1 or .2, for paired-end data.\nIf the --split-output flag is also given, this file is generated\nin addition to the output in the .nomapping file.")), ToolInput(tag="in_append_output", input_type=Boolean(optional=True), prefix="--append-output", doc=InputDocumentation(doc="When --split-output or --failed-input is given, this flag will append output\nto the existing files.  Otherwise, the default is to create new files.")), ToolInput(tag="in_order_among_best", input_type=String(optional=True), prefix="--order-among-best", doc=InputDocumentation(doc="Among alignments tied with the best score, order those alignments in this order.\nAllowed values: genomic, random (default)")), ToolInput(tag="in_output_buffer_size", input_type=Int(optional=True), prefix="--output-buffer-size", doc=InputDocumentation(doc="Buffer size, in queries, for output thread (default 1000).  When the number\nof results to be printed exceeds this size, the worker threads are halted\nuntil the backlog is cleared")), ToolInput(tag="in_no_sam_headers", input_type=Boolean(optional=True), prefix="--no-sam-headers", doc=InputDocumentation(doc="Do not print headers beginning with '@'")), ToolInput(tag="in_add_paired_no_mappers", input_type=Boolean(optional=True), prefix="--add-paired-nomappers", doc=InputDocumentation(doc="Add nomapper lines as needed to make all paired-end results alternate\nbetween first end and second end")), ToolInput(tag="in_paired_flag_means_concordant", input_type=Int(optional=True), prefix="--paired-flag-means-concordant", doc=InputDocumentation(doc="Whether the paired bit in the SAM flags means concordant only (1)\nor paired plus concordant (0, default)")), ToolInput(tag="in_sam_headers_batch", input_type=Int(optional=True), prefix="--sam-headers-batch", doc=InputDocumentation(doc="Print headers only for this batch, as specified by -q")), ToolInput(tag="in_sam_hard_clip_use_s", input_type=Boolean(optional=True), prefix="--sam-hardclip-use-S", doc=InputDocumentation(doc="Use S instead of H for hardclips")), ToolInput(tag="in_sam_use_zero_m", input_type=Boolean(optional=True), prefix="--sam-use-0M", doc=InputDocumentation(doc="Insert 0M in CIGAR between adjacent insertions, deletions, and introns\nPicard disallows 0M, other tools may require it")), ToolInput(tag="in_sam_extended_cigar", input_type=Boolean(optional=True), prefix="--sam-extended-cigar", doc=InputDocumentation(doc="Use extended CIGAR format (using X and = symbols instead of M,\nto indicate matches and mismatches, respectively")), ToolInput(tag="in_sam_multiple_primaries", input_type=Boolean(optional=True), prefix="--sam-multiple-primaries", doc=InputDocumentation(doc="Allows multiple alignments to be marked as primary if they\nhave equally good mapping scores")), ToolInput(tag="in_sam_sparse_secondaries", input_type=File(optional=True), prefix="--sam-sparse-secondaries", doc=InputDocumentation(doc="For secondary alignments (in multiple mappings), uses '*' for SEQ\nand QUAL fields, to give smaller file sizes.  However, the output\nwill give warnings in Picard to give warnings and may not work\nwith downstream tools")), ToolInput(tag="in_force_xs_dir", input_type=Boolean(optional=True), prefix="--force-xs-dir", doc=InputDocumentation(doc="For RNA-Seq alignments, disallows XS:A:? when the sense direction\nis unclear, and replaces this value arbitrarily with XS:A:+.\nMay be useful for some programs, such as Cufflinks, that cannot\nhandle XS:A:?.  However, if you use this flag, the reported value\nof XS:A:+ in these cases will not be meaningful.")), ToolInput(tag="in_md_lowercase_snp", input_type=Boolean(optional=True), prefix="--md-lowercase-snp", doc=InputDocumentation(doc="In MD string, when known SNPs are given by the -v flag,\nprints difference nucleotides as lower-case when they,\ndiffer from reference but match a known alternate allele")), ToolInput(tag="in_extend_soft_clips", input_type=Boolean(optional=True), prefix="--extend-soft-clips", doc=InputDocumentation(doc="Extends alignments through soft clipped regions")), ToolInput(tag="in_action_if_cigar_error", input_type=Boolean(optional=True), prefix="--action-if-cigar-error", doc=InputDocumentation(doc="Action to take if there is a disagreement between CIGAR length and sequence length\nAllowed values: ignore, warning (default), noprint, abort\nNote that the noprint option does not print the CIGAR string at all if there\nis an error, so it may break a SAM parser")), ToolInput(tag="in_read_group_id", input_type=String(optional=True), prefix="--read-group-id", doc=InputDocumentation(doc="Value to put into read-group id (RG-ID) field")), ToolInput(tag="in_read_group_name", input_type=String(optional=True), prefix="--read-group-name", doc=InputDocumentation(doc="Value to put into read-group name (RG-SM) field")), ToolInput(tag="in_read_group_library", input_type=String(optional=True), prefix="--read-group-library", doc=InputDocumentation(doc="Value to put into read-group library (RG-LB) field")), ToolInput(tag="in_read_group_platform", input_type=String(optional=True), prefix="--read-group-platform", doc=InputDocumentation(doc="Value to put into read-group library (RG-PL) field")), ToolInput(tag="in_check", input_type=Boolean(optional=True), prefix="--check", doc=InputDocumentation(doc="Check compiler assumptions")), ToolInput(tag="in_hash_offsets_hash", input_type=String(), position=0, doc=InputDocumentation(doc="Hash offsets  Hash positions  Genome          Local hash offsets  Local hash positions\n0      allocate      mmap            mmap            allocate            mmap\n1      allocate      mmap & preload  mmap            allocate            mmap & preload\n2      allocate      mmap & preload  mmap & preload  allocate            mmap & preload\n3      allocate      allocate        mmap & preload  allocate            allocate"))], outputs=[ToolOutput(tag="out_split_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_split_output", type_hint=File()), doc=OutputDocumentation(doc="Basename for multiple-file output, separately for nomapping,\nhalfmapping_uniq, halfmapping_mult, unpaired_uniq, unpaired_mult,\npaired_uniq, paired_mult, concordant_uniq, and concordant_mult results")), ToolOutput(tag="out_output_file", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_file", type_hint=File()), doc=OutputDocumentation(doc="File name for a single stream of output results.")), ToolOutput(tag="out_sam_sparse_secondaries", output_type=File(optional=True), selector=InputSelector(input_to_select="in_sam_sparse_secondaries", type_hint=File()), doc=OutputDocumentation(doc="For secondary alignments (in multiple mappings), uses '*' for SEQ\nand QUAL fields, to give smaller file sizes.  However, the output\nwill give warnings in Picard to give warnings and may not work\nwith downstream tools"))], container="quay.io/biocontainers/gmap:2020.10.14--pl526h2f06484_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Gsnapl_Sse42_V0_1_0().translate("wdl")

